@@ -1,11 +1,13 @@
 
+import os
 import sys
+from os import path
 
 from rvirtualenv.copy import copy
 from rvirtualenv.generate import generate
 
 
-VERSION = (0, 2, 2)
+VERSION = (0, 2, 3)
 __version__ = VERSION
 __versionstr__ = '.'.join(map(str, VERSION))
 
@@ -20,7 +22,7 @@ def main(argv=None):
     if len(argv) < 2:
         raise NotImplementedError
 
-    venv = argv[1]
+    venv = path.join(os.getcwd(), argv[1])
 
     copy(venv)
     generate(venv)
